/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2010 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp10nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp10nid ;

DATA library.&dataset ;
INFILE datafile LRECL=1794;
INPUT
   DISGORGE  1              BUSTEXT $ 2-15           OWNSTEXT $ 16         
   FINSTXT $ 17-33          FINDOTXT $ 34            OFENTXT1 $ 35         
   OFENTXT2 $ 36            OFENTXT3 $ 37            PRMONTXT $ 38-87      
   ORDERTXT $ 88-186        TYPEOTTX $ 187-377       CPIDN  378-384        
   PSR  385                 JANDC  386               PLEA  387             
   REASONS  388             INDICT  389              SENTRANS  390         
   WRKSHT  391              INCORPYR  392-395        INCORLOC  396         
   ORGTYPE  397             BUSCLAS  398-401         FTEMNUM  402-405      
   FTEMSIGN  406            SELFREP  407             HSMISCND  408         
   PRCRIME  409             PRCIVIL  410             OWNSTRCT  411         
   FINSTDS  412             FINSTDO  413             OFFENSE1  414         
   OFFENSE2  415            OFFENSE3  416            PRIMOFF  417-418      
   NOCOUNTS  419-420        SOURCES  421             OFFLVL  422-423       
   DETBFINE  424            TOLERNCE  425            HISTORY  426          
   VIOLATE  427             OBSTRUCT  428            COMPLY  429           
   ACCEPT  430-431          CCULPSCO  432-433        FCULPSCO  434-435     
   MINFINML  436-439        MAXFINML  440-442        DISPOSIT  443         
   PROBATN  444-445         COFI  446                PROBMON  447          
   ORDERCE  448             TYPEOTHS  449-450        CRIMPURP  451         
   CANTPAY  452             ADJOFL1  453-454         ADJOFL2  455-456      
   ADJOFLHI  457-458        ADJ_B1  459-460          ADJ_B2  461-462       
   ADJ_BHI  463-464         ADJ_C1  465-467          ADJ_C2  468           
   ADJ_CHI  469-471         ADJ_D1  472-473          ADJ_D2  474           
   ADJ_DHI  475-476         ADJ_E1  477              ADJ_E2  478           
   ADJ_EHI  479             ADJ_F1  480              ADJ_F2  481           
   ADJ_FHI  482             ADJ_G1  483              ADJ_G2  484           
   ADJ_GHI  485             ADJ_H1  486              ADJ_H2  487           
   ADJ_HHI  488             ADJ_I1  489              ADJ_I2  490           
   ADJ_IHI  491             ADJ_J1  492              ADJ_J2  493           
   ADJ_JHI  494             ADJ_K1  495              ADJ_K2  496           
   ADJ_KHI  497             ADJ_L1  498              ADJ_L2  499           
   ADJ_LHI  500             ADJ_M1  501              ADJ_M2  502           
   ADJ_MHI  503             ADJ_N1  504              ADJ_N2  505           
   ADJ_NHI  506             ADJ_O1  507              ADJ_O2  508           
   ADJ_OHI  509             ADJ_P1  510              ADJ_P2  511           
   ADJ_PHI  512             BASADJ1  513             BASADJ2  514          
   BASADJHI  515            BASE1  516-517           BASE2  518            
   BASEHI  519-520          ADJOFR1  521-522         ADJOFR2  523          
   ADJOFRHI  524-525        ADJR_B1  526-527         ADJR_B2  528          
   ADJR_BHI  529-530        ADJR_C1  531             ADJR_C2  532          
   ADJR_CHI  533            ADJR_D1  534             ADJR_D2  535          
   ADJR_DHI  536            ADJR_E1  537             ADJR_E2  538          
   ADJR_EHI  539            ADJR_F1  540             ADJR_F2  541          
   ADJR_FHI  542            ADJR_G1  543             ADJR_G2  544          
   ADJR_GHI  545            ADJR_H1  546             ADJR_H2  547          
   ADJR_HHI  548            ADJR_I1  549             ADJR_I2  550          
   ADJR_IHI  551            ADJR_J1  552             ADJR_J2  553          
   ADJR_JHI  554            ADJR_K1  555             ADJR_K2  556          
   ADJR_KHI  557            ADJR_L1  558             ADJR_L2  559          
   ADJR_LHI  560            ADJR_M1  561             ADJR_M2  562          
   ADJR_MHI  563            ADJR_N1  564             ADJR_N2  565          
   ADJR_NHI  566            ADJR_O1  567             ADJR_O2  568          
   ADJR_OHI  569            ADJR_P1  570             ADJR_P2  571          
   ADJR_PHI  572            BASADR1  573             BASADR2  574          
   BASADRHI  575            BASER1  576              BASER2  577           
   BASERHI  578             ADJOFS1  579-580         ADJOFS2  581-582      
   ADJOFSHI  583-584        ADJS_B1  585-586         ADJS_B2  587-588      
   ADJS_BHI  589-590        ADJS_C1  591-593         ADJS_C2  594          
   ADJS_CHI  595-597        ADJS_D1  598-599         ADJS_D2  600          
   ADJS_DHI  601-602        ADJS_E1  603             ADJS_E2  604          
   ADJS_EHI  605            ADJS_F1  606             ADJS_F2  607          
   ADJS_FHI  608            ADJS_G1  609             ADJS_G2  610          
   ADJS_GHI  611            ADJS_H1  612             ADJS_H2  613          
   ADJS_HHI  614            ADJS_I1  615             ADJS_I2  616          
   ADJS_IHI  617            ADJS_J1  618             ADJS_J2  619          
   ADJS_JHI  620            ADJS_K1  621             ADJS_K2  622          
   ADJS_KHI  623            ADJS_L1  624             ADJS_L2  625          
   ADJS_LHI  626            ADJS_M1  627             ADJS_M2  628          
   ADJS_MHI  629            ADJS_N1  630             ADJS_N2  631          
   ADJS_NHI  632            ADJS_O1  633             ADJS_O2  634          
   ADJS_OHI  635            ADJS_P1  636             ADJS_P2  637          
   ADJS_PHI  638            BASADS1  639             BASADS2  640          
   BASADSHI  641            BASES1  642-643          BASES2  644           
   BASESHI  645-646         ADJOFC1  647             ADJOFC2  648          
   ADJOFCHI  649            ADJC_B1  650             ADJC_B2  651          
   ADJC_BHI  652            ADJC_C1  653             ADJC_C2  654          
   ADJC_CHI  655            ADJC_D1  656             ADJC_D2  657          
   ADJC_DHI  658            ADJC_E1  659             ADJC_E2  660          
   ADJC_EHI  661            ADJC_F1  662             ADJC_F2  663          
   ADJC_FHI  664            ADJC_G1  665             ADJC_G2  666          
   ADJC_GHI  667            ADJC_H1  668             ADJC_H2  669          
   ADJC_HHI  670            ADJC_I1  671             ADJC_I2  672          
   ADJC_IHI  673            ADJC_J1  674             ADJC_J2  675          
   ADJC_JHI  676            ADJC_K1  677             ADJC_K2  678          
   ADJC_KHI  679            ADJC_L1  680             ADJC_L2  681          
   ADJC_LHI  682            ADJC_M1  683             ADJC_M2  684          
   ADJC_MHI  685            ADJC_N1  686             ADJC_N2  687          
   ADJC_NHI  688            ADJC_O1  689             ADJC_O2  690          
   ADJC_OHI  691            ADJC_P1  692             ADJC_P2  693          
   ADJC_PHI  694            BASADC1  695             BASADC2  696          
   BASADCHI  697            BASEC1  698              BASEC2  699           
   BASECHI  700             ADJL_B1 $ 701            ADJL_B2 $ 702         
   ADJL_BHI $ 703           ADJL_C1 $ 704-705        ADJL_C2 $ 706         
   ADJL_CHI $ 707-708       ADJL_D1 $ 709-710        ADJL_D2 $ 711         
   ADJL_DHI $ 712-713       ADJL_E1 $ 714            ADJL_E2 $ 715         
   ADJL_EHI $ 716           ADJL_F1 $ 717            ADJL_F2 $ 718         
   ADJL_FHI $ 719           ADJL_G1 $ 720            ADJL_G2 $ 721         
   ADJL_GHI $ 722           ADJL_H1 $ 723            ADJL_H2 $ 724         
   ADJL_HHI $ 725           ADJL_I1 $ 726            ADJL_I2 $ 727         
   ADJL_IHI $ 728           ADJL_J1 $ 729            ADJL_J2 $ 730         
   ADJL_JHI $ 731           ADJL_K1 $ 732            ADJL_K2 $ 733         
   ADJL_KHI $ 734           ADJL_L1 $ 735            ADJL_L2 $ 736         
   ADJL_LHI $ 737           ADJL_M1 $ 738            ADJL_M2 $ 739         
   ADJL_MHI $ 740           ADJL_N1 $ 741            ADJL_N2 $ 742         
   ADJL_NHI $ 743           ADJL_O1 $ 744            ADJL_O2 $ 745         
   ADJL_OHI $ 746           ADJL_P1 $ 747            ADJL_P2 $ 748         
   ADJL_PHI $ 749           BASEL1 $ 750             BASEL2 $ 751          
   BASELHI $ 752            ADRL_B1 $ 753            ADRL_B2 $ 754         
   ADRL_BHI $ 755           ADRL_C1 $ 756-757        ADRL_C2 $ 758         
   ADRL_CHI $ 759-760       ADRL_D1 $ 761            ADRL_D2 $ 762         
   ADRL_DHI $ 763           ADRL_E1 $ 764            ADRL_E2 $ 765         
   ADRL_EHI $ 766           ADRL_F1 $ 767            ADRL_F2 $ 768         
   ADRL_FHI $ 769           ADRL_G1 $ 770            ADRL_G2 $ 771         
   ADRL_GHI $ 772           ADRL_H1 $ 773            ADRL_H2 $ 774         
   ADRL_HHI $ 775           ADRL_I1 $ 776            ADRL_I2 $ 777         
   ADRL_IHI $ 778           ADRL_J1 $ 779            ADRL_J2 $ 780         
   ADRL_JHI $ 781           ADRL_K1 $ 782            ADRL_K2 $ 783         
   ADRL_KHI $ 784           ADRL_L1 $ 785            ADRL_L2 $ 786         
   ADRL_LHI $ 787           ADRL_M1 $ 788            ADRL_M2 $ 789         
   ADRL_MHI $ 790           ADRL_N1 $ 791            ADRL_N2 $ 792         
   ADRL_NHI $ 793           ADRL_O1 $ 794            ADRL_O2 $ 795         
   ADRL_OHI $ 796           ADRL_P1 $ 797            ADRL_P2 $ 798         
   ADRL_PHI $ 799           BASERL1 $ 800            BASERL2 $ 801         
   BASERLHI $ 802           ADSL_B1 $ 803            ADSL_B2 $ 804         
   ADSL_BHI $ 805           ADSL_C1 $ 806-807        ADSL_C2 $ 808         
   ADSL_CHI $ 809-810       ADSL_D1 $ 811-812        ADSL_D2 $ 813         
   ADSL_DHI $ 814-815       ADSL_E1 $ 816            ADSL_E2 $ 817         
   ADSL_EHI $ 818           ADSL_F1 $ 819            ADSL_F2 $ 820         
   ADSL_FHI $ 821           ADSL_G1 $ 822            ADSL_G2 $ 823         
   ADSL_GHI $ 824           ADSL_H1 $ 825            ADSL_H2 $ 826         
   ADSL_HHI $ 827           ADSL_I1 $ 828            ADSL_I2 $ 829         
   ADSL_IHI $ 830           ADSL_J1 $ 831            ADSL_J2 $ 832         
   ADSL_JHI $ 833           ADSL_K1 $ 834            ADSL_K2 $ 835         
   ADSL_KHI $ 836           ADSL_L1 $ 837            ADSL_L2 $ 838         
   ADSL_LHI $ 839           ADSL_M1 $ 840            ADSL_M2 $ 841         
   ADSL_MHI $ 842           ADSL_N1 $ 843            ADSL_N2 $ 844         
   ADSL_NHI $ 845           ADSL_O1 $ 846            ADSL_O2 $ 847         
   ADSL_OHI $ 848           ADSL_P1 $ 849            ADSL_P2 $ 850         
   ADSL_PHI $ 851           BASESL1 $ 852            BASESL2 $ 853         
   BASESLHI $ 854           ADCL_B1 $ 855            ADCL_B2 $ 856         
   ADCL_BHI $ 857           ADCL_C1 $ 858            ADCL_C2 $ 859         
   ADCL_CHI $ 860           ADCL_D1 $ 861            ADCL_D2 $ 862         
   ADCL_DHI $ 863           ADCL_E1 $ 864            ADCL_E2 $ 865         
   ADCL_EHI $ 866           ADCL_F1 $ 867            ADCL_F2 $ 868         
   ADCL_FHI $ 869           ADCL_G1 $ 870            ADCL_G2 $ 871         
   ADCL_GHI $ 872           ADCL_H1 $ 873            ADCL_H2 $ 874         
   ADCL_HHI $ 875           ADCL_I1 $ 876            ADCL_I2 $ 877         
   ADCL_IHI $ 878           ADCL_J1 $ 879            ADCL_J2 $ 880         
   ADCL_JHI $ 881           ADCL_K1 $ 882            ADCL_K2 $ 883         
   ADCL_KHI $ 884           ADCL_L1 $ 885            ADCL_L2 $ 886         
   ADCL_LHI $ 887           ADCL_M1 $ 888            ADCL_M2 $ 889         
   ADCL_MHI $ 890           ADCL_N1 $ 891            ADCL_N2 $ 892         
   ADCL_NHI $ 893           ADCL_O1 $ 894            ADCL_O2 $ 895         
   ADCL_OHI $ 896           ADCL_P1 $ 897            ADCL_P2 $ 898         
   ADCL_PHI $ 899           BASECL1 $ 900            BASECL2 $ 901-903     
   BASECLHI $ 904           GDLINE1 $ 905-909        GDLINE2 $ 910-914     
   GDSTAT1 $ 915-919        GDSTAT2 $ 920-924        GDREF1 $ 925-929      
   GDREF2 $ 930             GDCROS1 $ 931            GDCROS2 $ 932         
   NOCOMP  933              GDLINEHI $ 934-938       GDSTATHI $ 939-943    
   GDREFHI $ 944-948        GDCROSHI $ 949           SMIN1  950            
   SMIN2  951               SMIN3  952               SMIN4  953            
   SMIN5  954               SMIN6  955               SMIN7  956            
   SMIN8  957               SMIN9  958               SMIN10  959           
   SMIN11  960              SMIN12  961              SMIN13  962           
   SMIN14  963              SMIN15  964              SMIN16  965           
   SMIN17  966              SMIN18  967              SMIN19  968           
   SMIN20  969              SMIN21  970              SMIN22  971           
   SMIN23  972              SMIN24  973              SMIN25  974           
   SMIN26  975              SMIN27  976              SMIN28  977           
   SMAX1  978-986           SMAX2  987-993           SMAX3  994-1000       
   SMAX4  1001-1007         SMAX5  1008-1014         SMAX6  1015-1021      
   SMAX7  1022-1028         SMAX8  1029-1035         SMAX9  1036-1042      
   SMAX10  1043-1049        SMAX11  1050-1055        SMAX12  1056-1061     
   SMAX13  1062-1067        SMAX14  1068-1073        SMAX15  1074-1079     
   SMAX16  1080-1085        SMAX17  1086-1091        SMAX18  1092-1097     
   SMAX19  1098-1104        SMAX20  1105-1111        SMAX21  1112-1118     
   SMAX22  1119-1125        SMAX23  1126-1132        SMAX24  1133-1139     
   SMAX25  1140-1146        SMAX26  1147-1153        SMAX27  1154-1160     
   SMAX28  1161-1167        STA1_1 $ 1168-1177       STA1_2 $ 1178-1186    
   STA1_3 $ 1187-1198       STA1_4 $ 1199-1207       STA1_5 $ 1208-1216    
   STA1_6 $ 1217-1225       STA1_7 $ 1226-1234       STA1_8 $ 1235-1243    
   STA1_9 $ 1244-1252       STA1_10 $ 1253-1260      STA1_11 $ 1261-1268   
   STA1_12 $ 1269-1276      STA1_13 $ 1277-1284      STA1_14 $ 1285-1292   
   STA1_15 $ 1293-1300      STA1_16 $ 1301-1308      STA1_17 $ 1309-1316   
   STA1_18 $ 1317-1324      STA1_19 $ 1325-1332      STA1_20 $ 1333-1340   
   STA1_21 $ 1341-1348      STA1_22 $ 1349-1356      STA1_23 $ 1357-1364   
   STA1_24 $ 1365-1372      STA1_25 $ 1373-1380      STA1_26 $ 1381-1388   
   STA1_27 $ 1389-1396      STA1_28 $ 1397-1401      STA2_1 $ 1402-1411    
   STA2_2 $ 1412-1419       STA2_3 $ 1420-1427       STA2_4 $ 1428-1434    
   STA2_5 $ 1435-1440       STA2_6 $ 1441-1447       STA2_7 $ 1448-1454    
   STA2_8 $ 1455-1461       STA2_9 $ 1462-1467       STA2_10 $ 1468-1473   
   STA2_11 $ 1474-1479      STA2_12 $ 1480-1482      STA2_13 $ 1483-1488   
   STA2_14 $ 1489-1494      STA2_15 $ 1495-1500      STA2_16 $ 1501-1503   
   STA2_17 $ 1504           STA2_18 $ 1505           STA2_19 $ 1506        
   STA2_20 $ 1507           STA2_21 $ 1508           STA2_22 $ 1509        
   STA2_23 $ 1510           STA2_24 $ 1511           STA2_25 $ 1512        
   STA2_26 $ 1513           STA2_27 $ 1514           STA2_28 $ 1515        
   STA3_1 $ 1516-1523       STA3_2 $ 1524-1530       STA3_3 $ 1531-1537    
   STA3_4 $ 1538-1540       STA3_5 $ 1541-1547       STA3_6 $ 1548-1550    
   STA3_7 $ 1551-1559       STA3_8 $ 1560-1562       STA3_9 $ 1563-1569    
   STA3_10 $ 1570           STA3_11 $ 1571           STA3_12 $ 1572        
   STA3_13 $ 1573           STA3_14 $ 1574           STA3_15 $ 1575        
   STA3_16 $ 1576           STA3_17 $ 1577           STA3_18 $ 1578        
   STA3_19 $ 1579           STA3_20 $ 1580           STA3_21 $ 1581        
   STA3_22 $ 1582           STA3_23 $ 1583           STA3_24 $ 1584        
   STA3_25 $ 1585           STA3_26 $ 1586           STA3_27 $ 1587        
   STA3_28 $ 1588           NWSTAT1 $ 1589-1598      NWSTAT2 $ 1599-1608   
   NWSTAT3 $ 1609-1620      NWSTAT4 $ 1621-1628      NWSTAT5 $ 1629-1636   
   NWSTAT6 $ 1637-1641      NWSTAT7 $ 1642-1645      NOUSTAT  1646         
   AMENDYR  1647-1650       BASEFINE  1651-1660      CH2APP  1661          
   CH8FINGD  1662           CMSRVORD  1663           COMPLYPR  1664        
   COSTASSM  1665           FINOFFST  1666-1671      FORFEITR  1672-1681   
   GLFINMAX  1682-1691      GLFINMIN  1692-1701      REMEDORD  1702-1704   
   VICTNOTE  1705           BOOKERCD  1706-1707      QUARTER  1708         
   RETEXT1 $ 1709           RETEXT2 $ 1710-1720      RETEXT3 $ 1721        
   RETEXT4 $ 1722           RETEXT5 $ 1723           RETEXT6 $ 1724        
   RETEXT7 $ 1725           RETEXT8 $ 1726           RETEXT9 $ 1727        
   RETEXT10 $ 1728          REAS1  1729-1731         REAS2  1732-1734      
   REAS3  1735-1737         REAS4  1738              REAS5  1739-1741      
   REAS6  1742-1744         REAS7  1745              REAS8  1746           
   REAS9  1747              REAS10  1748             INPLEA1  1749         
   INPLEA2  1750            INPLEA3  1751            INPLEA4  1752         
   INPLEA5  1753            INPLEA6  1754            INPLEA7  1755         
   INPLEA8  1756            INPLEA9  1757            INPLEA10  1758        
   INPLEA11  1759           INPLEA12  1760           INNOPL1  1761         
   INNOPL2  1762            INNOPL3  1763            INNOPL4  1764         
   INNOPL5  1765            INNOPL6  1766            INNOPL7  1767         
   INNOPL8  1768            INNOPL9  1769            INNOPL10  1770        
   INNOPL11  1771           INNOPL12  1772           SENTYR  1773-1776     
   BOOKER2  1777            BOOKER3  1778            NEWCNVTN  1779        
   RESTCAT  1780            FINECAT  1781            SUSFNCAT  1782        
   LCAT1  1783              LCAT2  1784              LCATHI  1785          
   LCATS1  1786             LCATS2  1787             LCATSHI  1788         
   LCATR1  1789             LCATR2  1790             LCATRHI  1791         
   LCATC1  1792             LCATC2  1793             LCATCHI  1794         
 ;                       

LENGTH
   DISGORGE 3               CPIDN 6                  PSR 3                 
   JANDC 3                  PLEA 3                   REASONS 3             
   INDICT 3                 SENTRANS 3               WRKSHT 3              
   INCORPYR 4               INCORLOC 3               ORGTYPE 3             
   BUSCLAS 4                FTEMNUM 4                FTEMSIGN 3            
   SELFREP 3                HSMISCND 3               PRCRIME 3             
   PRCIVIL 3                OWNSTRCT 3               FINSTDS 3             
   FINSTDO 3                OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               PRIMOFF 3                NOCOUNTS 3            
   SOURCES 3                OFFLVL 3                 DETBFINE 3            
   TOLERNCE 3               HISTORY 3                VIOLATE 3             
   OBSTRUCT 3               COMPLY 3                 ACCEPT 3              
   CCULPSCO 3               FCULPSCO 3               DISPOSIT 3            
   PROBATN 3                COFI 3                   PROBMON 3             
   ORDERCE 3                TYPEOTHS 3               CRIMPURP 3            
   CANTPAY 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                NOCOMP 3                 SMIN1 3               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 NOUSTAT 3                AMENDYR 4             
   BASEFINE 6               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COMPLYPR 3               COSTASSM 3            
   FINOFFST 6               GLFINMAX 6               GLFINMIN 6            
   REMEDORD 4               VICTNOTE 3               BOOKERCD 3            
   QUARTER 3                REAS1 4                  REAS2 4               
   REAS3 4                  REAS4 3                  REAS5 4               
   REAS6 4                  REAS7 3                  REAS8 3               
   REAS9 3                  REAS10 3                 INPLEA1 3             
   INPLEA2 3                INPLEA3 3                INPLEA4 3             
   INPLEA5 3                INPLEA6 3                INPLEA7 3             
   INPLEA8 3                INPLEA9 3                INPLEA10 3            
   INPLEA11 3               INPLEA12 3               INNOPL1 3             
   INNOPL2 3                INNOPL3 3                INNOPL4 3             
   INNOPL5 3                INNOPL6 3                INNOPL7 3             
   INNOPL8 3                INNOPL9 3                INNOPL10 3            
   INNOPL11 3               INNOPL12 3               SENTYR 4              
   BOOKER2 3                BOOKER3 3                NEWCNVTN 3            
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATCHI 3 ;

         

RUN ;
